# Changelog

## 0.1.0-alpha.1 (2025-03-11)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/sullyai/sullyai-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([#4](https://github.com/sullyai/sullyai-python/issues/4)) ([c17774d](https://github.com/sullyai/sullyai-python/commit/c17774da22f1390cf4abb6545b54d46c65565da8))
* **api:** api update ([#6](https://github.com/sullyai/sullyai-python/issues/6)) ([b1b23b0](https://github.com/sullyai/sullyai-python/commit/b1b23b061e778fa80846e7c2fb400c72c14f1b67))
* **api:** manual updates ([#5](https://github.com/sullyai/sullyai-python/issues/5)) ([1f43b70](https://github.com/sullyai/sullyai-python/commit/1f43b70f4900c587c41cf6baa2da5d77ae519062))


### Chores

* go live ([#1](https://github.com/sullyai/sullyai-python/issues/1)) ([0b58e83](https://github.com/sullyai/sullyai-python/commit/0b58e833a7d5d818b0f21d6c206c476affdb0056))
* update SDK settings ([#3](https://github.com/sullyai/sullyai-python/issues/3)) ([fbd61f1](https://github.com/sullyai/sullyai-python/commit/fbd61f12cb82075dab7772cf44e09b408c0b5ead))
